@@ -1,3 +1,10 @@
+/* 
+ * Copyright (c) 2010 Craig Heffner
+ *
+ * This software is provided under the MIT license. For the full text of this license, please see
+ * the COPYING file included with this code, or visit http://www.opensource.org/licenses/MIT.
+ */
+
 #ifndef FILTER_H
 #define FILTER_H
 
@@ -35,12 +42,12 @@ struct magic_signature
         char *signature;
 };
 
-void uppercase(char *string);
-int string_contains(char *haystack, char *needle);
 void free_filters(struct magic_filter *filters[], int filter_count);
 enum filter_result_t grep_check(struct magic_filter *filters[], int filter_count, char *description);
 enum filter_result_t filter_check(struct magic_filter *filters[], int filter_count, char *description);
 void add_filter(struct magic_filter *filters[], int *filter_count, enum filter_type_t type, char* filter);
+int is_repeat_of_many(char *match);
+int jump_to_offset(char *match);
 
 void free_signatures(struct magic_signature **signatures, int num_sigs);
 void add_signature(struct magic_signature **signatures, int *num_sigs, int magic_size, int magic_offset, int wildcard, char *magic);
